Class: Stellar::Homework::Submission
- Inherits:
-
Object
- Object
- Stellar::Homework::Submission
- Defined in:
- lib/stellar/homework.rb
Overview
A student's submission for an assignment.
Defined Under Namespace
Classes: Comment
Instance Attribute Summary collapse
-
#client ⇒ Object
readonly
Generic Stellar client used to make requests.
-
#comments ⇒ Object
readonly
Comments posted on this submission.
-
#email ⇒ Object
readonly
Email of the student who authored this submission.
-
#file_url ⇒ Object
readonly
URL to the last file that the student submitted.
-
#homework ⇒ Object
readonly
Homework that the submission belongs to.
-
#name ⇒ Object
readonly
Name of the student who authored this submission.
-
#time ⇒ Object
readonly
Submission time.
Instance Method Summary collapse
-
#add_comment(text, file_data = nil, file_mime_type = 'text/plain', file_name = 'attachment.txt') ⇒ Stellar::Homework::Submission
Adds a comment to the student's submission.
-
#file_data ⇒ String
The contents of the file attached to this Stellar submission.
-
#initialize(tr, homework) ⇒ Submission
constructor
Creates a submission from a
element in the Stellar homework page. - #reload_comments!(page = nil) ⇒ Object
Reloads the problem set's comments page.
Constructor Details
#initialize(tr, homework) ⇒ Submission
Creates a submission from a
element in the Stellar homework page. - #reload_comments!(page = nil) ⇒ Object